summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kcautoconfigmodule.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kcautoconfigmodule.h')
-rw-r--r--kopete/libkopete/kcautoconfigmodule.h27
1 files changed, 14 insertions, 13 deletions
diff --git a/kopete/libkopete/kcautoconfigmodule.h b/kopete/libkopete/kcautoconfigmodule.h
index fcca6047..d09173ea 100644
--- a/kopete/libkopete/kcautoconfigmodule.h
+++ b/kopete/libkopete/kcautoconfigmodule.h
@@ -33,14 +33,14 @@ class KConfig;
*
* This class makes it very easy to create a configuration page using KAutoConfig.
* All you need to do is create a class that is derived from KCAutoConfigModule, create your
- * config page with QDesigner, and add it to the module
+ * config page with TQDesigner, and add it to the module
* This can be done using the setMainWidget() method:
* \code
* typedef KGenericFactory<MyPageConfig, TQWidget> MyPageConfigFactory;
* K_EXPORT_COMPONENT_FACTORY( kcm_mypageconfig, MyPageConfigFactory( "kcm_mypageconfig" ) )
*
* MyPageConfig( TQWidget * parent, const char *, const TQStringList & args )
* : KCAutoConfigModule( MyPageConfigFactory::instance(), parent, args )
* {
* setMainWidget( new MyPageConfigBase(this) , "MyGroup" );
* }
@@ -53,44 +53,45 @@ class KConfig;
class KOPETE_EXPORT KCAutoConfigModule : public KCModule
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Standard KCModule constructor. Use KGlobal::config()
*/
- KCAutoConfigModule( TQWidget * parent = 0, const char * name = 0, const TQStringList & args = TQStringList() );
+ KCAutoConfigModule( TQWidget * tqparent = 0, const char * name = 0, const TQStringList & args = TQStringList() );
/**
* Standard KCModule constructor. Use KGlobal::config()
*/
- KCAutoConfigModule( KInstance * instance, TQWidget * parent = 0, const TQStringList & args = TQStringList() );
+ KCAutoConfigModule( KInstance * instance, TQWidget * tqparent = 0, const TQStringList & args = TQStringList() );
/**
* Constructor.
* @param config the KConfig to use
* @param instance KInstance object for this KCM
* @param parent parent widget
* @param args special arguments for this KCM
*
* @todo document what the args mean (inherited from KCModule?)
*/
- KCAutoConfigModule(KConfig* config, KInstance * instance, TQWidget * parent = 0, const TQStringList & args = TQStringList() );
+ KCAutoConfigModule(KConfig* config, KInstance * instance, TQWidget * tqparent = 0, const TQStringList & args = TQStringList() );
/**
* Constructor, much like the one above, except with
* no instance and with a name.
* @param config the KConfig to use
* @param parent parent widget
* @param name name of the object
* @param args special arguments for this KCM
*/
- KCAutoConfigModule(KConfig* config, TQWidget * parent = 0, const char * name=0 , const TQStringList & args = TQStringList() );
+ KCAutoConfigModule(KConfig* config, TQWidget * tqparent = 0, const char * name=0 , const TQStringList & args = TQStringList() );
~KCAutoConfigModule();
/**
* Set the main widget. @p widget will be lay out to take all available place in the module.
* @p widget must have this module as parent.
*
* This method automatically call KAutoConfig::addWidget() and KAutoConfig::retrieveSettings()
*
@@ -113,7 +114,7 @@ class KOPETE_EXPORT KCAutoConfigModule : public KCModule
/**
* Reload the config from the configfile.
*
* You can also reimplement this method, but you should always call the parent KCModule::load()
* be sure you know what you are doing
*/
virtual void load();
@@ -121,7 +122,7 @@ class KOPETE_EXPORT KCAutoConfigModule : public KCModule
/**
* Save the config to the configfile.
*
* You can also reimplement this method, but you should always call the parent KCModule::save()
* be sure you know what you are doing
*/
virtual void save();
@@ -129,7 +130,7 @@ class KOPETE_EXPORT KCAutoConfigModule : public KCModule
/**
* Reload the default config
*
* You can also reimplement this method, but you should always call the parent KCModule::defaults()
* be sure you know what you are doing
*/
virtual void defaults();
@@ -33,14 +33,14 @@ class KConfig;
* K_EXPORT_COMPONENT_FACTORY( kcm_mypageconfig, MyPageConfigFactory( "kcm_mypageconfig" ) )
*
- * MyPageConfig( TQWidget * parent, const char *, const TQStringList & args )
- * : KCAutoConfigModule( MyPageConfigFactory::instance(), parent, args )
+ * MyPageConfig( TQWidget * tqparent, const char *, const TQStringList & args )
+ * : KCAutoConfigModule( MyPageConfigFactory::instance(), tqparent, args )
* {
* setMainWidget( new MyPageConfigBase(this) , "MyGroup" );
@@ -53,44 +53,45 @@ class KConfig;
* @param config the KConfig to use
* @param instance KInstance object for this KCM
- * @param parent parent widget
+ * @param tqparent tqparent widget
* @param args special arguments for this KCM
*
@@ -53,44 +53,45 @@ class KConfig;
* no instance and with a name.
* @param config the KConfig to use
- * @param parent parent widget
+ * @param tqparent tqparent widget
* @param name name of the object
* @param args special arguments for this KCM
@@ -53,44 +53,45 @@ class KConfig;
/**
* Set the main widget. @p widget will be lay out to take all available place in the module.
- * @p widget must have this module as parent.
+ * @p widget must have this module as tqparent.
*
* This method automatically call KAutoConfig::addWidget() and KAutoConfig::retrieveSettings()
@@ -113,7 +114,7 @@ class KOPETE_EXPORT KCAutoConfigModule : public KCModule
* Reload the config from the configfile.
*
- * You can also reimplement this method, but you should always call the parent KCModule::load()
+ * You can also reimplement this method, but you should always call the tqparent KCModule::load()
* be sure you know what you are doing
*/
@@ -121,7 +122,7 @@ class KOPETE_EXPORT KCAutoConfigModule : public KCModule
* Save the config to the configfile.
*
- * You can also reimplement this method, but you should always call the parent KCModule::save()
+ * You can also reimplement this method, but you should always call the tqparent KCModule::save()
* be sure you know what you are doing
*/
@@ -129,7 +130,7 @@ class KOPETE_EXPORT KCAutoConfigModule : public KCModule
* Reload the default config
*
- * You can also reimplement this method, but you should always call the parent KCModule::defaults()
+ * You can also reimplement this method, but you should always call the tqparent KCModule::defaults()
* be sure you know what you are doing
*/